ffastdb library
Classes
- BufferedStorageStrategy
- Buffered storage strategy — wraps any StorageStrategy with two optimizations:
- EncryptedStorageStrategy
- A wrapper StorageStrategy that obfuscates data before writing to the base strategy and de-obfuscates it after reading.
- FastDB
- FastDB — A high-performance, pure-Dart NoSQL database.
- FFastDB
- Marks a Dart class as a FFastDB model / collection.
- FFastDbSingleton
- The type of the global ffastdb singleton.
- FFastField
- Associates a field with a stable serialization slot n.
- FFastId
- Marks the integer primary-key field of the collection.
- FFastIndex
- Creates a secondary index on the annotated field.
- FieldCondition
- IoStorageStrategy
- Mobile/Desktop storage implementation using RandomAccessFile.
- MemoryStorageStrategy
- In-memory storage implementation for testing and Web fallback.
- QueryBuilder
- Fluent query builder with a Cost-Based Optimizer (CBO).
- QueryResult
- Result of a query — a list of document IDs to fetch.
- StorageStrategy
- Base interface for storage operations on different platforms.
- WalStorageStrategy
- WAL (Write-Ahead Log) storage strategy.
- WebStorageStrategy
- In-memory storage strategy for web.
Properties
- ffastdb → FFastDbSingleton
-
Global FFastDB instance — the single entry-point to the database,
analogous to Hive's top-level
Hiveobject.final - pid_ → int
-
final
Functions
-
openDatabase(
String name, {String directory = '', int cacheCapacity = 256, double autoCompactThreshold = double.minPositive, int version = 1, Map< int, dynamic Function(dynamic)> ? migrations, List<String> indexes = const [], List<String> sortedIndexes = const [], String? encryptionKey}) → Future<FastDB> -
Opens (or creates) a named database in
directory.